==> scipion-em-sphire-1.4.0.tar.gz: scipion-em-sphire-1.4.0/sphire/objects.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (delarosatrevin@scilifelab.se) [1]
# *
# * [1] SciLifeLab, Stockholm University
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

import pyworkflow.object as pwobj
from pyworkflow.em.data import EMObject


class CryoloModel(EMObject):
    """ Simple class to store the Cryolo training model path. """
    def __init__(self, path=None, **kwargs):
        EMObject.__init__(self, **kwargs)
        self._path = pwobj.String(path)

    def getPath(self):
        return self._path.get()

    def setPath(self, path):
        self._path.set(path)

    def __str__(self):
        return "CryoloModel(path=%s)" % self.getPath()

==> scipion-em-sphire-3.0.0.tar.gz: scipion-em-sphire-3.0.0/sphire/objects.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (delarosatrevin@scilifelab.se) [1]
# *
# * [1] SciLifeLab, Stockholm University
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

import pyworkflow.object as pwobj
from pwem import EMObject


class CryoloModel(EMObject):
    """ Simple class to store the Cryolo training model path. """
    def __init__(self, path=None, **kwargs):
        EMObject.__init__(self, **kwargs)
        self._path = pwobj.String(path)

    def getPath(self):
        return self._path.get()

    def setPath(self, path):
        self._path.set(path)

    def __str__(self):
        return "CryoloModel(path=%s)" % self.getPath()
